
import java.awt.*;
import java.applet.Applet;
import java.io.IOException;
import java.net.URL;
import java.net.MalformedURLException;

public class LTBrowser extends Applet
{
	RecordFilter	fFilter;
	RecordDisplay	fDisplay;
	protected	final	boolean	gRunLocal = false;
	private		LassoRequest	fRequest;
	
	public void init() 
	{
		setLayout(new GridBagLayout());
		setBackground(Color.white);
		setFont(new Font("Helvetica", Font.PLAIN, 10));
		
		fRequest = new LassoRequest(getParameter("lasso_name"));
		fRequest.setDatabaseName(getParameter("db_name"));
		fRequest.setLayoutName(getParameter("layout_name"));
		fRequest.setAction(LassoRequest.FIELD_INFO);
		fRequest.setMaxRecords(LassoRequest.ALL);
		
		LassoResponse	response = null;
		
		try 
		{
			response = (new LassoProxy(getDocumentBase(), getParameter("lasso_name"))).processRequest(fRequest); 
					
			int	cfi = response.fieldIndex(getParameter("catfield_name"));
			int	tfi = response.fieldIndex(getParameter("typefield_name"));
		
			fFilter = new RecordFilter(	getParameter("catfield_name"), response.fieldValueList(cfi), 
							getParameter("typefield_name"), response.fieldValueList(tfi));
			
			GBConstrainer.constrain(this, fFilter, 0, 0, 1, 1, false);
			
			fFilter.setFont(getFont());
			Component[]	cs = fFilter.getComponents();
			for (int i = 0; i < cs.length; ++i)
				cs[i].setFont(getFont());
			
			GBConstrainer.constrain(this, new ImageButton(getImage(getDocumentBase(), "images/leftup.gif"), 
											getImage(getDocumentBase(), "images/leftdown.gif"), 
											"Previous"),
								0, 1, 1, 1, 
								/*insets*/1, 48, 1, 1, false, GridBagConstraints.EAST);
								
			GBConstrainer.constrain(this, new ImageButton(getImage(getDocumentBase(), "images/rightup.gif"), 
											getImage(getDocumentBase(), "images/rightdown.gif"), 
											"Next"),
								0, 2, 1, 1, false, GridBagConstraints.WEST);
			
			fDisplay = new RecordDisplay();
			GBConstrainer.constrain(this, fDisplay, 1, 0, 3, 1, false);
			
			fDisplay.setFont(getFont());
			cs = fDisplay.getComponents();
			for (int i = 0; i < cs.length; ++i)
				cs[i].setFont(getFont());
			
			updateDisplay();			
		}
		catch(IOException e) { System.out.println(e.toString()); return; }
		catch(FieldNotFoundException e) { System.out.println(e.toString()); return; }
	}
	
	public void paint(Graphics g)
	{
		super.paint(g);
//		GridBagDebugger.debug(this);
	}
	
	private void updateDisplay()
	{
		Frame	top = getTopFrame();
		int		oldCursor = 0;
		if (top != null)
		{
			oldCursor = top.getCursorType();
			top.setCursor(Frame.WAIT_CURSOR);
		}
		
		fFilter.filterRequest(fRequest);
		fRequest.setAction(fRequest.numSearchFields() > 0 ? LassoRequest.SEARCH : LassoRequest.FIND_ALL);
		try
		{
			fDisplay.setResponse((new LassoProxy(getDocumentBase(), getParameter("lasso_name"))).processRequest(fRequest));
		} catch(IOException e)
		{ System.out.println(e.toString()); }
		finally
		{	
			if (top != null)
				top.setCursor(oldCursor);
		}
	}
	
	private final Frame getTopFrame()
	{
		Frame	topFrame = null;	
		Component	c = this, p = null;
		while (true)
		{
			p = c.getParent();
			if (p != null)
			{
				if (p instanceof Frame)
					break;
			}
			else
				break;
			c = p;
			p = null;		
		}
		topFrame = (Frame)p;
		
		return topFrame;
	}
	
	public URL getDocumentBase()
	{
		try
		{
			if (gRunLocal)
				return new URL("http://209.19.18.248/ltb/");
			return super.getDocumentBase();
		}
		catch(MalformedURLException e){}
		return null;
	}
	
	public boolean action(Event evt, Object what)
	{
		if (what instanceof String)
		{	
			// see if the user pushed the next of previous buttons
			String	label = (String)what;
			if (label.equals("Previous"))
			{
				fDisplay.previousRecord();
				return true;
			}
			else if (label.equals("Next"))
			{
				fDisplay.nextRecord();
				return true;
			}
			
			// see if the user selected from the "Browse By" popup menus
			if (evt.target instanceof Choice)
			{
				updateDisplay();
			}
		}
		return false;
	}
	
}
