import java.awt.*;

public class RecordDisplay extends Panel
{
	private	LassoResponse	fResponse = null;
	
	private	TextField		fTagCategory,
						fTagType,
						fName,
						fTag;
	private	TextArea		fDescription,
						fHTMLCode;
	private	Label			fNumTagsShown, fCurrentTagShown;			
	private	int			fCurrentRecord = 0;
	private	int			fFieldIndexes[];
	
	public RecordDisplay()
	{
		setLayout(new GridBagLayout());
		
		fTagCategory = new TextField(25);
		fTagType = new TextField(25);
		fTag = new TextField(25);
		fName = new TextField(25);
		fHTMLCode = new TextArea(5, 40);
		fDescription = new TextArea(10, 40);
		fNumTagsShown = new Label("0");
		fCurrentTagShown = new Label("0");
		
		GBConstrainer.constrain(this, new Label("Name:", Label.RIGHT), 
									0, 0, 1, 1, false, GridBagConstraints.EAST);
		GBConstrainer.constrain(this, fName, 	0, 1, 1, 1, false);
		GBConstrainer.constrain(this, new Label("Tag:", Label.RIGHT), 
									1, 0, 1, 1, false, GridBagConstraints.EAST);
		GBConstrainer.constrain(this, fTag, 	1, 1, 1, 1, false);
		
		GBConstrainer.constrain(this, new Label("Description:", Label.RIGHT), 
									2, 0, 1, 1, false, GridBagConstraints.NORTHEAST);
		GBConstrainer.constrain(this, fDescription, 
									2, 1, 1, 3, true);
		
		
		GBConstrainer.constrain(this, new Label("Category:", Label.RIGHT), 
									0, 2, 1, 1, false, GridBagConstraints.EAST);
		GBConstrainer.constrain(this, fTagCategory, 
									0, 3, 2, 1, false);
		GBConstrainer.constrain(this, new Label("Type:", Label.RIGHT), 
									1, 2, 1, 1, false, GridBagConstraints.EAST);
		GBConstrainer.constrain(this, fTagType, 
									1, 3, 2, 1, false);
		
		GBConstrainer.constrain(this, new Label("HTML:", Label.RIGHT), 
									2, 2, 1, 1, false, GridBagConstraints.NORTHEAST);
		GBConstrainer.constrain(this, fHTMLCode, 
									2, 3, 2, 1, true);
		
		
		
		GBConstrainer.constrain(this, new Label("Number of tags shown: ", Label.RIGHT), 
									3, 3, 1, 1, false, GridBagConstraints.NORTHEAST);
		GBConstrainer.constrain(this, fNumTagsShown, 
									3, 4, 1, 1, false, GridBagConstraints.NORTHWEST);
		
		GBConstrainer.constrain(this, new Label("Current tag shown: ", Label.RIGHT), 
									4, 3, 1, 1, false, GridBagConstraints.NORTHEAST);
		GBConstrainer.constrain(this, fCurrentTagShown, 
									4, 4, 1, 1, false, GridBagConstraints.NORTHWEST);
		
		fFieldIndexes = new int[6];
	}
	
	public void setResponse(LassoResponse resp)
	{	
		fResponse = resp;
		fCurrentRecord = 0;
		fNumTagsShown.setText(String.valueOf(fResponse.numRecords()));
		
		try
		{
			fFieldIndexes[0] = fResponse.fieldIndex("Name_LassoTags");
			fFieldIndexes[1] = fResponse.fieldIndex("tag");
			fFieldIndexes[2] = fResponse.fieldIndex("Tag_Category");
			fFieldIndexes[3] = fResponse.fieldIndex("Tag_Type");
			fFieldIndexes[4] = fResponse.fieldIndex("HTMLCode");
			fFieldIndexes[5] = fResponse.fieldIndex("Description");			
		}
		catch(FieldNotFoundException  e)
		{}
		updateDisplay();
	}
	
	public Insets insets()
	{	return new Insets(7, 7, 7, 7);	}
	
	private void updateDisplay()
	{
		if (fResponse == null) return;
		
//		// make sure this is a real tag record and not a heading
//		while (fResponse.fieldValue(fCurrentRecord, fFieldIndexes[1], 0).length() < 1)
//			++fCurrentRecord;
		
		// if there are no tags to show, show no tags
		if (fResponse.resultCode() != LassoResponse.NOERROR || fResponse.numRecords() == 0)
		{
			fCurrentTagShown.setText("0");
			fName.setText("");
			fTag.setText("");
			fTagCategory.setText("");
			fTagType.setText("");
			fHTMLCode.setText("");
			fDescription.setText("");
			return;
		}
		
		// display index as one based
		fCurrentTagShown.setText(String.valueOf(fCurrentRecord + 1));
		
		String	temp = fResponse.fieldValue(fCurrentRecord, fFieldIndexes[0], 0);
		
		fName.setText(temp);
		fName.select(0, 0);
		
		temp = fResponse.fieldValue(fCurrentRecord, fFieldIndexes[1], 0);
		
		fTag.setText(temp);
		fTag.select(0, 0);
		
		temp = fResponse.fieldValue(fCurrentRecord, fFieldIndexes[2], 0);
		
		fTagCategory.setText(temp);
		fTagCategory.select(0, 0);
		
		temp = fResponse.fieldValue(fCurrentRecord, fFieldIndexes[3], 0);
		
		fTagType.setText(temp);
		fTagType.select(0, 0);
		
		temp = TextWrapper.wrap(fResponse.fieldValue(fCurrentRecord, fFieldIndexes[4], 0), 45);
		
		fHTMLCode.setText(temp);
		fHTMLCode.select(0, 0);
		
		temp = TextWrapper.wrap(fResponse.fieldValue(fCurrentRecord, fFieldIndexes[5], 0), 45);
		
		fDescription.setText(temp);
		fDescription.select(1, 1);
	}
	
	public void paint(Graphics g)
	{
		super.paint(g);
		g.setColor(Color.gray);
		g.draw3DRect(3, 3, size().width - 6, size().height - 6, false);
		
//		GridBagDebugger.debug(this);
	}
	
	public void nextRecord()
	{
		if (fResponse.numRecords() == 1) return;
		++fCurrentRecord;
		if (fCurrentRecord == fResponse.numRecords())
			fCurrentRecord = 0;
		updateDisplay();
	}
	
	public void previousRecord()
	{
		if (fResponse.numRecords() == 1) return;
		--fCurrentRecord;
		if (fCurrentRecord < 0)
			fCurrentRecord = fResponse.numRecords() - 1;
		updateDisplay();
	}
}
